==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ytbchoicewithcontainerandleaflist/rev20160826/ytbchoicewithcontainerandleaflist/contenttest/DefaultChoiceContainer.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.ContentTest;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of choiceContainer.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultChoiceContainer extends InnerModelObject implements ChoiceContainer {
    protected org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.ChoiceContainer choiceContainer;

    @Override
    public org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.ChoiceContainer choiceContainer() {
        return choiceContainer;
    }

    @Override
    public void choiceContainer(org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.ChoiceContainer choiceContainer) {
        this.choiceContainer = choiceContainer;
    }

    @Override
    public int hashCode() {
        return Objects.hash(choiceContainer);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultChoiceContainer) {
            DefaultChoiceContainer other = (DefaultChoiceContainer) obj;
            return
                Objects.equals(choiceContainer, other.choiceContainer);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("choiceContainer=" + choiceContainer)
            .toString();
    }


    /**
     * Creates an instance of defaultChoiceContainer.
     */
    public DefaultChoiceContainer() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbchoicewithcontainerandleaflist/rev20160826/ytbchoicewithcontainerandleaflist/contenttest/DefaultChoiceContainer.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.ContentTest;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of choiceContainer.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultChoiceContainer extends InnerModelObject implements ChoiceContainer {
    protected org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.ChoiceContainer choiceContainer;

    @Override
    public org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.ChoiceContainer choiceContainer() {
        return choiceContainer;
    }

    @Override
    public void choiceContainer(org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.ChoiceContainer choiceContainer) {
        this.choiceContainer = choiceContainer;
    }

    @Override
    public int hashCode() {
        return Objects.hash(choiceContainer);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultChoiceContainer) {
            DefaultChoiceContainer other = (DefaultChoiceContainer) obj;
            return
                Objects.deepEquals(choiceContainer, other.choiceContainer);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("choiceContainer=" + choiceContainer)
            .toString();
    }


    /**
     * Creates an instance of defaultChoiceContainer.
     */
    public DefaultChoiceContainer() {
    }

}
